# verb-reflinks [![NPM version](https://img.shields.io/npm/v/verb-reflinks.svg?style=flat)](https://www.npmjs.com/package/verb-reflinks) [![NPM downloads](https://img.shields.io/npm/dm/verb-reflinks.svg?style=flat)](https://npmjs.org/package/verb-reflinks) [![Build Status](https://img.shields.io/travis/verbose/verb-reflinks.svg?style=flat)](https://travis-ci.org/verbose/verb-reflinks)

Verb middleware that resolves reflinks for valid npm package names in markdown documents and appends them to the document.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install --save verb-reflinks
```

**Why should I use use?**

`verb-reflinks` makes it easy to write documentation that references other libraries, by simply adding the name, like `[foo][]`, without having to remember or write the entire URL to the GitHub repository.

## Usage

Use as a `.postRender` or `.preWrite` middleware.

```js
var reflinks = require('verb-reflinks');
var verb = require('verb');
var app = verb();

app.postRender(/\.md$/, reflinks());
```

**What does this do?**

* Finds reflinks like `[gulp][]` or `[gulp]`
* Resolves the `homepage` or `repository.url` from the [npm](https://www.npmjs.com) package name
* Appends the resolve reflink, `[gulp]: http://gulpjs.com`, to the markdown string if it doesn't already exist

**Must be a valid npm name**

For reflinks to be fixed, the reflink text must match the name of a valid npm package. For example `[Foo Bar][]` won't be resolved, but `[gulp][]` would.

## Related projects

You might also be interested in these projects:

* [gulp-reflinks](https://www.npmjs.com/package/gulp-reflinks): Gulp plugin for `reflinks`. Lints a markdown string to find missing reflinks for npm package… [more](https://github.com/jonschlinkert/gulp-reflinks) | [homepage](https://github.com/jonschlinkert/gulp-reflinks "Gulp plugin for `reflinks`. Lints a markdown string to find missing reflinks for npm package names, resolves the homepage or repository url from npm, and appends a valid reflink to the document.")
* [reflinks](https://www.npmjs.com/package/reflinks): Generate (relative) reference links for a glob of markdown files, allowing you to more easily… [more](https://github.com/jonschlinkert/reflinks) | [homepage](https://github.com/jonschlinkert/reflinks "Generate (relative) reference links for a glob of markdown files, allowing you to more easily create references from one file to another.")
* [verb](https://www.npmjs.com/package/verb): Documentation generator for GitHub projects. Verb is extremely powerful, easy to use, and is used… [more](https://github.com/verbose/verb) | [homepage](https://github.com/verbose/verb "Documentation generator for GitHub projects. Verb is extremely powerful, easy to use, and is used on hundreds of projects of all sizes to generate everything from API docs to readmes.")

## Contributing

This document was generated by [verb-readme-generator](https://github.com/verbose/verb-readme-generator) (a [verb](https://github.com/verbose/verb) generator), please don't edit directly. Any changes to the readme must be made in [.verb.md](.verb.md). See [Building Docs](#building-docs).

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](../../issues/new).

Or visit the [verb-readme-generator](https://github.com/verbose/verb-readme-generator) project to submit bug reports or pull requests for the readme layout template.

## Building docs

_(This document was generated by [verb-readme-generator](https://github.com/verbose/verb-readme-generator) (a [verb](https://github.com/verbose/verb) generator), please don't edit the readme directly. Any changes to the readme must be made in [.verb.md](.verb.md).)_

Generate readme and API documentation with [verb](https://github.com/verbose/verb):

```sh
$ npm install -g verb verb-readme-generator && verb
```

## Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

## Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2016, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT license](https://github.com/verbose/verb-reflinks/blob/master/LICENSE).

***

_This file was generated by [verb](https://github.com/verbose/verb), v0.9.0, on July 13, 2016._